`unittest/simple-test.l` でユニットテストを書く際に便利な関数やマクロ
がいくつか定義されています。


テスト用ユーティリティの説明
============================

Function `test-uid`
-------------------
ユニークな整数を返します。
テスト用にユニークな名前を生成する場合などに利用します。

Variable `*test-temp-buffer-delete*`
------------------------------------
一時バッファを使用後、削除するかどうかを指定します。

Macro `with-temp-buffer` &body BODY
-----------------------------------
一時バッファに移動して BODY を実行します。
BODY を実行後（`*test-temp-buffer-delete*` が nil でなければ）一時
バッファは削除されます。

Macro `compile-and-eval` &body BODY
-----------------------------------
BODY をコンパイルしてから実行します。
テストしたい問題がコンパイルした場合のみ発生するような場合に。

### 注意事項
- 実装上の都合で `compile-and-eval` の外にあるレキシカル変数などは参照
  できなくなります。

Function `eval-in-another-xyzzy` FORM &key OPTIONS TIMEOUT
----------------------------------------------------------
テストを実行してる xyzzy とは別にもう一つ xyzzy を起動して、そちらで
FORM を評価します。
FORM が正常に終了すれば FORM の返した値を返します。
FORM がエラーで終了すれば、そのエラーを投げます。

xyzzy が落ちたり固まったりしてしまうようなテストをする場合や、クリーン
な状態からテストしたい場合に使います。

OPTIONS にはキーワード引数で何か設定できます。

- :options コマンドライン引数（文字列）
  - もう一つの xyzzy に渡すコマンドライン引数
  - コマンドラインは $XYZZY/xyzzy.exe <コマンドライン引数> -e <FORM>
    のようになります。
  - 参考 [xyzzyの役に立たないReadme](http://www.jsdlab.co.jp/~kei/download/00README.html)
- :timeout タイムアウト[秒]
  - タイムアウトするまでの時間を秒で
  - もう一つの xyzzy が BODY の評価を終えられなかったり、結果を伝える
    のに失敗したりするとタイムアウトします
  - タイムアウトした場合は、`simple-error` を投げます

### 注意事項
- `eval-in-another-xyzzy` は FORM や戻り値やエラーを文字列にして受け渡す
  ので...
  - FORM や戻り値やエラーには、読み込み可能な形で出力できるものしか
    使えません。

Macro `with-fake-functions` ((NAME FAKE-LAMBDA-LIST &body FAKE-BODY)*) &body BODY)
----------------------------------------------------------------------------------
一時的にグローバルな関数定義を差し替えて BODY を実行します。
BODY を実行するとどこかで関数 NAME が呼び出されるのだけど、嬉しくない
副作用があったり面倒な準備が必要だったりする場合に使います。
差し替えられた関数は FAKE-LAMBDA-LIST と FAKE-BODY を使ったただの関数
なので、てきとーに値を返したりしてください。



